<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Cliquer pour revenir à l&apos;application</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Téléchargement(s)</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Nettoyer</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 élément</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publier Podcast sur YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tableau</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stylets</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fonds</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédente</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Page haut</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivante</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Page bas</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fond quadrillé clair</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fond quadrillé foncé</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Démarrer l&apos;enregistrement de l&apos;écran</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Surligneur</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Sélecteur</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Main</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zoomer en avant</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zoomer en arrière</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Capture</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Ajouter à la page courante</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Ajouter sur une nouvelle page</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Ajouter à la bibliothèque</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pages</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nouvelle page</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configurer le podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Capturer du contenu Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Capturer du contenu Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Capturer du contenu Web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Capturer du contenu Web</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Capture d&apos;une fenêtre</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Montrer sur l&apos;écran de projection</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Trait</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stylet</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Gomme</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Changer le fond d&apos;écran</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Gérer les documents</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Parcourir le Web</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Ligne fine</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Ligne moyenne</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Ligne large</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Gomme fine</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Gomme moyenne</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Gomme large</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Couleur</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédente</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Suivante</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Recharger la page courante</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Charger la page d&apos;accueil</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Afficher les favoris</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Ajouter un favori</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Afficher le tableau</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Effacer le contenu</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Afficher les préférences</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Afficher la bibliothèque</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Afficher le bureau de l&apos;ordinateur</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Créer un nouveau dossier</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Créer un nouveau document</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importer un document</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exporter un document</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Ouvrir la page dans le tableau</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Dupliquer le contenu sélectionné</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Supprimer le contenu sélectionné</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Ajouter un contenu au document</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Maj+H</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Renommer le contenu</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Afficher les outils</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Utiliser un format large (16/9)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Utiliser un format normal (4/3)</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Utiliser un format de document personnalisé</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Arrêter le chargement de la page Web</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Mettre la présentation en pause</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Afficher le clavier virtuel</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Enregistrer la présentation en vidéo</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Effacer les éléments</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Effacer tous les éléments</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Effacer les annotations</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Effacer toutes les annotations</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Effacer la page</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Effacer tous les éléments</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Annoter le document</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Effacer l&apos;annotation</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Surligner </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Sélectionner et modifier des objets</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Déplacer la page</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Utiliser le &quot;pointeur laser&quot;</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Utiliser le &quot;pointeur laser&quot;</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Tracer une ligne droite</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Ecrire un texte</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Ajouter l&apos;élément à la page courante</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Ajouter l&apos;élément à une nouvelle page</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Ajouter l&apos;élément à la bibliothèque</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Créer une nouvelle page</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Dupliquer la page</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Dupliquer la page courante</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importer une page</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importer une page externe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Mettre en pause l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Configuration du podcast</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Contrôler la mise à jour</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturer une partie de l&apos;écran</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Capture personnalisée</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Capturer une fenêtre</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Embarquer un contenu Web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Capturer un contenu Web embarquable</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Afficher l&apos;écran principal sur l&apos;écran d&apos;affichage</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Effacer toutes les annotations</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importer une simulation eduMedia</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Ajouter le contenu sélectionné au document ouvert</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Veille</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Clavier virtuel</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fond clair uni</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fond sombre uni</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sombre</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Format large (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Format normal (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Format personnalisé</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Plus grand</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Plus petit</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Ouvrir la page</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multi-écrans</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nouveau document</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Ajouter au document</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Accueil</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Signets</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Signet</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Quitter OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Cacher OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Masquer OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translatorcomment>j&apos;hésite avec Lancer (dépend du contexte d&apos;usage)</translatorcomment>
        <translation>Jouer</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interagir avec des objets</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Effacer le fond</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Supprimer le fond</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Tutoriels</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Ouvrir la page Web des tutoriels</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Fond ligné clair</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Fond ligné foncé</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Réinitialiser la taille du quadrillage</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation>Gomme fine</translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation>Couleur 1</translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation>Couleur 2</translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation>Couleur 3</translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation>Couleur 4</translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation>Couleur 5</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Dessiner des lignes intermédiaires</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentification requise</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Authentification sur le proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Se connecter par le proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Enregistrer le nom d&apos;utilisateur et le mot de passe pour la prochaine.utilisation</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID de l&apos;élément = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Contenu non supporté dans le format souhaité.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Supprimer la page</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Voulez-vous vraiment effacer 1 page de ce document &apos;%0&apos;?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Taille de la page</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nouvelle mise à jour disponible : voulez-vous accéder à la page de téléchargement ?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Pas de mise à jour disponible</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Mise à jour disponible</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <source>Drawing active scene and thumbnail previews</source>
        <translation type="vanished">Dessin de la page active et des aperçus</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Dessin du tableau...</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Taille du quadrillage</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Dessiner des lignes intermédiaires</translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Erreur de téléchargement du contenu %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Téléchargement terminé</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Type d&apos;outil inconnu %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Ajouter un élément</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tous (%1)</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Type de contenu inconnu (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Supprimer la page %1 du document</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Page %1 supprimée</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Echec d&apos;ajout de document : erreur de copie</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grouper</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Dégrouper</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Sauvegarde du document...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Le document vient d&apos;être sauvegardé...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>Supression de la page %1</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Erreur lors de l&apos;ajout d&apos;images à la bibliothèque</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Image capturée</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Chargement page (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Propriétés du cache</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forme :</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturer une partie de l&apos;écran</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Capturer l&apos;écran</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Afficher la barre d&apos;outils du stylet</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Afficher le tableau sur l&apos;écran secondaire</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Afficher le bureau sur l&apos;écran secondaire</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Afficher OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Aucun document sélectionné !</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Ouvrir un fichier compatible</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Ajouter un dossier d&apos;images</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Ajouter des images</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Ajouter des pages depuis un fichier</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Copie du document %1 en cours</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Document %1 copié</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Supprimer la page</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Supprimer le document</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Vider la corbeille</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Voulez-vous vraiment vider la corbeille ?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Supression du contenu de la corbeille</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Corbeille vidée</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Supprimer le dossier</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Voulez-vous vraiment supprimer le dossier &apos;%1&apos; et tout son contenu ?</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importation du fichier %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Impossible d&apos;importer le fichier ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importer toutes les images d&apos;un dossier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vider</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Ouvrir le document</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Ajouter toutes les images au document</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Toutes les images (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>La sélection ne contient aucune image !</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Voulez-vous vraiment supprimer le document &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Page %1</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Voulez-vous vraiment effacer %n page de ce document &apos;%1&apos;?</numerusform>
            <numerusform>Voulez-vous vraiment effacer %n pages de ce document &apos;%1&apos;?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Le dossier ne contient pas d&apos;image</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documents sans titre</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>Le document &apos;%1&apos; a été créé avec une nouvelle version d&apos;OpenBoard (%2). En l&apos;ouvrant vous pourriez perdre des informations. Voulez-vous continuer ?</translation>
    </message>
    <message>
        <source>Remove mutliple documents</source>
        <translation type="vanished">Supprimer plusieurs documents</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Voulez-vous vraiment supprimer tous les documents sélectionnés?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Supprimer plusieurs documents</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>%1 page dupliquée</numerusform>
            <numerusform>%1 pages dupliquées</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Effacer les éléments</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Voulez-vous vraiment supprimer le(s) élément(s) sélectionné(s) ?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>page Titre</translation>
    </message>
    <message>
        <source>Empty My Documents</source>
        <translation type="vanished">Vider Mes Documents</translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>images</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>vidéos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objets</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>appliquettes</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Tous les fichiers supportés (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Fichier %1 enregistré</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Ajout de la page %1 sur %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importation réussie.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importation du document %1 réussie.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translatorcomment>j&apos;ai raccourci la phrase pour eviter les soucis de place !</translatorcomment>
        <translation>Importation de %1 en cours</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Page %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Echec de l&apos;export.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>Le nom %1 est déjà utilisé.
ATTENTION : En gardant ce nom, l&apos;ancien document sera écrasé par le nouveau.
Un nouveau nom vous permettra de conserver l&apos;ancien document.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation>Mes documents</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 page copiée</numerusform>
            <numerusform>%1 pages copiées</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 page copiée</numerusform>
            <numerusform>%1 pages copiées</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Effacer les éléments</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Voulez-vous vraiment supprimer le(s) élément(s) sélectionné(s) ?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation>Copie de la page %1/%2 en cours</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copie)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Copie de la page %1/%2 en cours</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 page copiée</numerusform>
            <numerusform>%1 pages copiées</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Téléchargement des fichiers en cours</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Page %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Page %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Avertissements lors de l&apos;exportation</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Export du document...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Echec de l&apos;export</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Impossible d&apos;exporter dans le dossier sélectionné. Vous n&apos;avez pas les permissions nécessaires pour sauvegarder le fichier.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Impossible d&apos;exporter: pas de droits d&apos;écriture dans le répertoire</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export réussi.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exporter au format CFF (*.iwb)</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exporter au format CFF (*.iwb)</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportation du document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export réussi.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Echec de l&apos;export.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exporter au format UBZ (*.ubz)</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export réussi.</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Page</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportation du document...</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportation %1 %2 sur %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exporter au format OpenBoard</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Impossible d&apos;exporter: pas de droits d&apos;écriture dans le répertoire</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Echec de l&apos;export</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossible d&apos;exporter dans le dossier sélectionné. Vous n&apos;avez pas les permissions nécessaires pour sauvegarder le fichier.</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation>Echec de l&apos;export...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Exporter au format UBX (*.ubx)</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Export du document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export réussi.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Echec de l&apos;export.</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>Exporter au format OpenBoard UBX</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporter au format PDF (*.pdf)</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportation du document...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporter au format PDF</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export terminé.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Impossible d&apos;exporter: pas de droits d&apos;écriture dans le répertoire</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Echec de l&apos;export</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossible d&apos;exporter dans le dossier sélectionné. Vous n&apos;avez pas les permissions nécessaires pour sauvegarder le fichier.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporter au format PDF (*.pdf)</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportation de la page %1 sur %2</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export terminé.</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportation du document...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporter au format PDF (*.pdf)</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Page</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exporter en tant que donnée Web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportation du document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export réussi.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Echec de l&apos;export.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exporter vers un navigateur Web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translatorcomment>j&apos;ai choisi de rendre le bouton plus compact (mais info moins complète)</translatorcomment>
        <translation>Ajout page</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translatorcomment>j&apos;ai choisi de rendre le bouton plus compact (mais info moins complète)</translatorcomment>
        <translation type="vanished">Ajout en fond</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translatorcomment>j&apos;ai choisi de rendre le bouton plus compact (mais info moins complète)</translatorcomment>
        <translation>Ajout bibliothèque</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informations</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Ajouter aux favoris</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Partager</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Retour au répertoire</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Supprimer des favoris</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Créer nouveau dossier</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Parcourir le système de fichiers</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Image importée</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Sons</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animations</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interactivités</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formes</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Recherche Web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Saisir le nom du nouveau dossier</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Chargement en cours </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Verrouillé</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible sur l&apos;écran étendu</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Verrouillé</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible sur l&apos;écran étendu</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Aller à la source du contenu</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Mettre en fond de page</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Ressource introuvable</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Format multimédia non supporté</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Service multimédia indisponible</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Erreur multimédia :</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Saisir votre texte ici&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Couleur du texte</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Éditable</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Chargement en cours ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Figé</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformer en outil</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Format de fichier CFF (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importation du fichier %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Echec de l&apos;import du fichier %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import terminée.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Echec de l&apos;import.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importation du fichier %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import terminé.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Échec de l&apos;import du fichier %1.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (set of documents) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Format d&apos;image (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Format PDF (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Échec de l&apos;import du fichier PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importation de la page %1 sur %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Erreur durant la publication de la vidéo sur l&apos;intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publication sur l&apos;intranet en cours %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publier</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Retour</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Renseigner le nom de l&apos;utilisateur et le mot de passe pour &quot;%1&quot; à %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Connexion au proxy impossible</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Erreur SSL (Secure Socket Layer) sur un serveur sécurisé:

%1

%2

Voulez-vous ignorer les erreurs pour ce serveur ?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Données d’Open-Sankoré détectées</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Afficher ce panneau à la prochaine ouverture du logiciel</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Vous pouvez accéder à nouveau à ce panneau au travers des Préférences dans l’onglet A propos. Attention, si vous avez déjà importé les données d’Open-Sankoré vous risquez de perdre les documents courants dans OpenBoard.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Procéder</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Des documents Open-Sankoré sont présents sur votre ordinateur. Il est possible de les importer dans OpenBoard en appuyant sur le bouton “Procéder” pour lancer le processus d’importation.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copie)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Accès perdu vers le répertoire des documents</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">a perdu l&apos;accès au répertoire des documents &apos;%1&apos;. Malheureusement, l&apos;application sera fermée afin d&apos;éviter la corruption des données. Les dernières modifications pourraient être également perdues.</translation>
    </message>
    <message>
        <source>saving document thumbnail for the page %1</source>
        <translation type="vanished">Sauvegarde aperçu page %1</translation>
    </message>
    <message>
        <source>Saving thumbnail of page %1</source>
        <translation type="vanished">Sauvegarde aperçu page %1</translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Déplacement de la page dans la corbeille...</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>OpenBoard a perdu l&apos;accès au répertoire des documents &apos;%1&apos;. Malheureusement, l&apos;application sera fermée afin d&apos;éviter la corruption des données. Les dernières modifications pourraient être également perdues.</translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russe</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Français suisse</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Échec du démarrage de l&apos;encodeur...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Aucun encodeur disponible.pour le podcast...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Partie %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>sur le bureau ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>dans le dossier %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast créé %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Erreur d&apos;enregistrement du podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Entrée audio par défaut</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Pas d&apos;enregistrement audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publier sur l&apos;intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publier sur Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Stylet sensible à la pression</translation>
    </message>
    <message>
        <source>version: </source>
        <translation>version : </translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Identification sur le Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Mot de passe :</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publier un fichier OpenBoard sur Planète-Sankoré</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titre :</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Description :</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publier</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mes films</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Réouvrir la prochaine fois</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Création de vignettes en cours ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 vignettes créées ...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">Chargement aperçu page %1</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Page %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Compass</source>
        <translation>Compas</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Règle</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Rapporteur</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation>Masque</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Équerre</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Loupe</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Spot</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation>Axes</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Page complète</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Mise à niveau du document</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>fichiers nécessitant une mise à jour.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Chemin de sauvegarde : </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Sélectionner un dossier de sauvegarde</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Fichiers mis à jour correctement !
Veuillez redémarrer l&apos;application pour accéder aux documents mis à jour.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Une erreur s&apos;est produite durant la mise à jour. Les fichiers n&apos;ont pas été affectés.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Résultats de la mise à jour</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Mise à jour du fichier</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Merci de patienter, le processus d&apos;import va commencer...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Me le rappeler plus tard</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Chargement...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 appelé (méthode=%1, statut=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Échec de l&apos;identification YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Erreur lors du transfert de la vidéo vers YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Transfert vers YouTube en cours %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Auto/Moto</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Animaux</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sports</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Voyages et événements</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Jeux vidéo et autres</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Humour</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Personnalités et blogues</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Actualités et politique</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Divertissement</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Éducation</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Vie pratique et style</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Organisations à but non lucratif</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Sciences et technologies</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Téléchargement annulé : %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Erreur durant l&apos;ouverture du fichier : %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Erreur lors de la sauvegarde du fichier : %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erreur réseau : %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 restante(s)</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 de %2 (%3/sec) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translatorcomment>si je me fie aux commentaires des développeurs...</translatorcomment>
        <translation>Taille de fichier inconnue</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - arrêté</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>octets</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Mo</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 téléchargement(s)</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 téléchargement(s)</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Précédemment dans la journée</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 élément(s)</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nouvel &amp;onglet</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Dupliquer onglet</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fermer onglet</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Fermer &amp;autres onglets</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recharger &amp;onglet</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recharger tous les onglets</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Onglets récemment fermés</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Sans titre)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Aucune recherche récente</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Historique des recherches</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Supprimer l&apos;historique des recherches</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Ajouter au document courant</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Erreur de chargement de la page : %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Téléchargement du PDF : préférez-vous télécharger le fichier PDF ou l&apos;ajouter à votre document courant ?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Ouvrir dans un nouvel onglet</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation>Traitement en cours...</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publier le podcast sur YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre du podcast</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Mots-clés</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nom d&apos;utilisateur YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Mot de passe YouTube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;En cliquant sur le bouton &quot;Téléchargement&quot;, vous certifiez que vous respectez les conditions générales d&apos;utilisation de YouTube &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Sauvegarder les paramètres de connexion</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>Opacité</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Sur fond clair</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sur fond foncé</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Largeur de ligne</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Large</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Visualiser la taille dès</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Stylet sensible à la pression</translation>
    </message>
    <message>
        <source>Smooth strokes (experimental)</source>
        <translation type="vanished">Lissage des traits (expérimental)</translation>
    </message>
    <message>
        <source>Simplify strokes after drawing (experimental)</source>
        <translation type="vanished">Simplification des traits post-dessin (expérimental)</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Courriel</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialogue</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="vanished">Courriel</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="vanished">Auteur</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Description</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Documents OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Date de création</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Date de modification</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Ordre alphabétique</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Ordre de tri</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Réglages par défaut</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Ouvrir la page dans un navigateur Web externe</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Clavier virtuel</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Taille des touches du clavier virtuel:</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Positionnée en haut (recommandé pour les tablettes)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Positionnée en bas (recommandé pour les tableaux interactifs)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Afficher les textes sous les boutons</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Mise à jour du logiciel</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Vérifier la mise à jour au lancement</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Page d&apos;accueil&#xa0;:</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>version :...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Barre du stylet</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stylo</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Surligneur</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licences</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Afficher le contenu du navigateur Web interne sur l&apos;écran de projection</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Multi-écrans</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Inverser la disposition des écrans</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Démarrer en mode :</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tableau</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy :</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Crédits</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Importateur de documents Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Vérifier si des données Open-Sankoré peuvent être importées au redémarrage</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Utiliser le clavier virtuel système (recommandé)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Taille des touches du clavier virtuel integré :</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Quadrillage</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sur fond foncé</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacité</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Sur fond clair</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Inverser les écrans élèves</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation>Mode Documents</translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation>Afficher la colonne des dates avec le tri alphabétique</translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation>Supprimer de la corbeille les documents de plus de</translation>
    </message>
    <message>
        <source>days</source>
        <translation>jours</translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation>Rendu PDF</translation>
    </message>
    <message>
        <source>Enable quality loss to increase zoom performances</source>
        <translation type="vanished">Activer la perte de qualité pour améliorer les performaces de zoom</translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation>Améliorer la vitesse d&apos;exécution du zoom (peut légèrement affecter la qualité du rendu)</translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Capturer du contenu Flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Sélectionner un contenu Flash à capturer</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>à propos : vide</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nom de l&apos;application</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Créer une application</translation>
    </message>
</context>
</TS>
